        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,7,8,9,10,13,15,19,20,21,24,26,28,29,30,32,33,35,36,37,38,39,40,41,44,47,48,49,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 17 <br>4,11,12,14,16,17,18,22,23,25,27,31,34,42,43,45,46';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,7,8,9,10,13,15,19,20,21,24,26,28,29,30,32,33,35,36,37,38,39,40,41,44,47,48,49,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 17 <br>4,11,12,14,16,17,18,22,23,25,27,31,34,42,43,45,46';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,7,8,9,10,13,15,19,20,21,24,26,28,29,30,32,33,35,36,37,38,39,40,41,44,47,48,49,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 17 <br>4,11,12,14,16,17,18,22,23,25,27,31,34,42,43,45,46';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,7,8,9,10,13,15,19,20,21,24,26,28,29,30,32,33,35,36,37,38,39,40,41,44,47,48,49,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 17 <br>4,11,12,14,16,17,18,22,23,25,27,31,34,42,43,45,46';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,7,8,9,10,13,15,19,20,21,24,26,28,29,30,32,33,35,36,37,38,39,40,41,44,47,48,49,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 17 <br>4,11,12,14,16,17,18,22,23,25,27,31,34,42,43,45,46';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,7,8,9,10,13,15,19,20,21,24,26,28,29,30,32,33,35,36,37,38,39,40,41,44,47,48,49,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260528 a 12</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 17 <br>4,11,12,14,16,17,18,22,23,25,27,31,34,42,43,45,46';}
}
